PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/Metrics.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Namespaces | Functions
Metrics.hpp File Reference

Go to the source code of this file.

## Namespaces
namespace | metrics

## Functions
Real | metrics::ConnectionLinkage (const Connection &, const Connection &, bool cross, Real ex=2.0, int log2StepSize=-3)
Real | metrics::ConnectionLinkage (const PCBoard &, Real ex, int log2StepSize)
uint | metrics::RatsNestCrossings (const PCBoard &)
void | metrics::SegmentParallelity (Real &cosine, Real &weight, const WideSegment_25 &, const WideSegment_25 &)